"""Define project metadata
"""

__all__ = [
    '__title__',
    '__summary__',
    '__url__',
    '__version__',
    '__author__',
    '__email__',
    '__license__',
]

__title__ = 'pydash'
__summary__ = 'Python port of Lo-Dash'
__url__ = 'https://github.com/dgilland/pydash'

__version__ = '1.0.0'

__author__ = 'Derrick Gilland'
__email__ = 'dgilland@gmail.com'

__license__ = 'MIT License'
